@@ -68,6 +68,16 @@ static void cc_from_hash(point_ptr p, int len, void *data)
     free(datacopy);
 }
 
+static void cc_neg(point_ptr r, point_ptr p)
+{
+    if (point_is_inf(p)) {
+	point_set_inf(r);
+	return;
+    }
+    point_set(r, p);
+    element_neg(r->y, r->y);
+}
+
 static void cc_add(point_ptr r, point_ptr p, point_ptr q)
 {
     if (point_is_inf(p)) {
@@ -188,6 +198,7 @@ void curve_init_cc_j(curve_ptr c, element_ptr j)
     c->random = cc_random;
     c->from_x = cc_from_x;
     c->from_hash = cc_from_hash;
+    c->neg = cc_neg;
     c->add = cc_add;
     c->mul = cc_mul;
     c->data = malloc(sizeof(common_curve_t));
@@ -213,6 +224,7 @@ void curve_init_cc_ab(curve_ptr c, element_ptr a, element_ptr b)
     c->random = cc_random;
     c->from_x = cc_from_x;
     c->from_hash = cc_from_hash;
+    c->neg = cc_neg;
     c->add = cc_add;
     c->mul = cc_mul;
     c->data = malloc(sizeof(common_curve_t));
@@ -244,6 +256,7 @@ void cc_switch_field(curve_ptr cnew, curve_ptr c, fieldmap_ptr map)
     common_curve_ptr ccnew, cc;
     cnew->field = map->dstfield;
     cnew->random = c->random;
+    cnew->neg = c->neg;
     cnew->add = c->add;
     cnew->mul = c->mul;
 
