@@ -5,13 +5,6 @@
 #include <stdlib.h>
 #include <gmp.h>
 
-extern gmp_randstate_t rs;
-
-static inline void rand_state_init()
-{
-    gmp_randinit_default(rs);
-}
-
 struct field_s;
 
 struct element_s {
@@ -189,4 +182,6 @@ static inline int element_length_in_bytes(element_ptr a)
 
 void field_init_fp(field_ptr f, mpz_t prime);
 void element_pow(element_ptr x, element_ptr a, mpz_ptr n);
+
+void random_set_file(char *);
 #endif //FIELD_H
