@@ -9,7 +9,7 @@ void cm_info_init(cm_info_t cm)
 {
     mpz_init(cm->q);
     mpz_init(cm->r);
-    mpz_init(cm->cofac);
+    mpz_init(cm->h);
     mpz_init(cm->n);
 }
 
@@ -17,7 +17,7 @@ void cm_info_clear(cm_info_t cm)
 {
     mpz_clear(cm->q);
     mpz_clear(cm->r);
-    mpz_clear(cm->cofac);
+    mpz_clear(cm->h);
     mpz_clear(cm->n);
 }
 
@@ -571,10 +571,11 @@ int mnt_step2(darray_ptr L, int D, mpz_t U)
 
     cm = malloc(sizeof(cm_info_t));
     cm_info_init(cm);
+    cm->k = 6;
     cm->D = D;
     mpz_set(cm->q, q);
     mpz_set(cm->r, r);
-    mpz_set(cm->cofac, cofac);
+    mpz_set(cm->h, cofac);
     mpz_set(cm->n, n);
     darray_append(L, cm);
 
@@ -587,7 +588,7 @@ int mnt_step2(darray_ptr L, int D, mpz_t U)
     return 0;
 }
 
-int find_mnt_curve(darray_t L, int D, int bitlimit)
+int find_mnt6_curve(darray_t L, int D, int bitlimit)
 {
     //first solve DV^2 = 3l^2 - 2l + 3
     //use variable subst U = 3l - 1 to transform equation
@@ -750,30 +751,31 @@ toobig:
     return found_count;
 }
 
-void compute_cm_curve(curve_ptr cc, field_ptr fp, cm_info_ptr cm)
+void compute_cm_curve(cc_param_ptr param, cm_info_ptr cm)
     //computes a curve and sets fp to the field it is defined over
     //using the complex multiplication method, where cm holds
     //the appropriate information (e.g. discriminant, field order)
 {
-    darray_t P;
+    darray_t coefflist;
     element_t hp, root;
-    field_t fpx;
+    field_t fp, fpx;
     int i, n;
+    curve_t cc;
 
     field_init_fp(fp, cm->q);
     field_init_poly(fpx, fp);
     element_init(hp, fpx);
 
-    darray_init(P);
+    darray_init(coefflist);
 
-    hilbert_poly(P, cm->D);
+    hilbert_poly(coefflist, cm->D);
 
     if (0) {
-	n = P->count;
+	n = coefflist->count;
 	printf("x^%d", n - 1);
 	printf("\n");
 	for (i=n-2; i>=0; i--) {
-	    mpz_out_str(stdout, 10, P->item[i]);
+	    mpz_out_str(stdout, 10, coefflist->item[i]);
 	    if (i) {
 		if (i == 1) {
 		    printf("x");
@@ -785,11 +787,13 @@ void compute_cm_curve(curve_ptr cc, field_ptr fp, cm_info_ptr cm)
 	}
     }
 
-    n = P->count;
+    n = coefflist->count;
     poly_alloc(hp, n);
     for (i=0; i<n; i++) {
-	element_set_mpz(poly_coeff(hp, i), P->item[i]);
+	element_set_mpz(poly_coeff(hp, i), coefflist->item[i]);
     }
+    //TODO: memory leak: clear elements of coefflist
+    darray_clear(coefflist);
     //TODO: remove x = 0, 1728 roots
     //TODO: what if there's no roots?
     /*
@@ -826,4 +830,29 @@ void compute_cm_curve(curve_ptr cc, field_ptr fp, cm_info_ptr cm)
 	}
 	point_clear(P);
     }
+
+    mpz_set(param->q, cm->q);
+    mpz_set(param->n, cm->n);
+    mpz_set(param->h, cm->h);
+    mpz_set(param->r, cm->r);
+    mpz_set(param->a, ((common_curve_ptr) cc->data)->a->data);
+    mpz_set(param->b, ((common_curve_ptr) cc->data)->b->data);
+    param->k = cm->k;
+    {
+	mpz_t z;
+	mpz_init(z);
+	//compute order of curve in F_q^k
+	//n = q - t + 1 hence t = q - n + 1
+	mpz_sub(z, param->q, param->n);
+	mpz_add_ui(z, z, 1);
+	compute_trace_n(z, param->q, z, param->k);
+	mpz_pow_ui(param->nk, param->q, param->k);
+	mpz_sub_ui(z, z, 1);
+	mpz_sub(param->nk, param->nk, z);
+	mpz_mul(z, param->r, param->r);
+	mpz_divexact(param->hk, param->nk, z);
+	mpz_clear(z);
+    }
+    curve_clear(cc);
+    field_clear(fp);
 }
