@@ -12,6 +12,11 @@ static void curve_group_clear(element_ptr e)
     free(e->data);
 }
 
+static void curve_group_invert(element_ptr x, element_ptr a)
+{
+    point_neg(x->data, a->data);
+}
+
 static void curve_group_mul(element_ptr x, element_ptr a, element_ptr b)
 {
     point_add(x->data, a->data, b->data);
@@ -69,6 +74,7 @@ void field_init_curve_group(field_t f, curve_t c, mpz_t cofac)
     mpz_set(p->cofac, cofac);
     f->init = curve_group_init;
     f->clear = curve_group_clear;
+    f->invert = curve_group_invert;
     f->mul = curve_group_mul;
     f->set1 = curve_group_set1;
     f->set = curve_group_set;
