@@ -19,15 +19,15 @@ int main()
     element_init(x, pairing->GT);
     element_random(g);
     printf("g = ");
-    element_out_str(stdout, g);
+    element_out_str(stdout, 0, g);
     printf("\n");
     element_random(h);
     printf("h = ");
-    element_out_str(stdout, h);
+    element_out_str(stdout, 0, h);
     printf("\n");
     bilinear_map(x, g, h, pairing);
     printf("f(g, h) = ");
-    element_out_str(stdout, x);
+    element_out_str(stdout, 0, x);
     printf("\n");
 
     mpz_init(z);
@@ -38,25 +38,25 @@ int main()
 
     element_pow(x, x, z);
     printf("f(g, h)^z = ");
-    element_out_str(stdout, x);
+    element_out_str(stdout, 0, x);
     printf("\n");
 
     element_pow(zg, g, z);
     printf("g^z = ");
-    element_out_str(stdout, zg);
+    element_out_str(stdout, 0, zg);
     printf("\n");
     bilinear_map(x, zg, h, pairing);
     printf("f(g^z, h) = ");
-    element_out_str(stdout, x);
+    element_out_str(stdout, 0, x);
     printf("\n");
 
     element_pow(zh, h, z);
     printf("h^z = ");
-    element_out_str(stdout, zh);
+    element_out_str(stdout, 0, zh);
     printf("\n");
     bilinear_map(x, g, zh, pairing);
     printf("f(g, h^z) = ");
-    element_out_str(stdout, x);
+    element_out_str(stdout, 0, x);
     printf("\n");
 
     return 0;
